@@ -69,7 +69,7 @@ class ClBuilderMenuAction(Action):
              Get('builder.cl_builder_livemenu_path') == "")
          },
         {'name': 'grub:setup_grub',
-         'message': __("Configuration grub {cl_builder_livemenu_path}"),
+         'message': __("Configuration grub for {cl_builder_livemenu_path}"),
          'method': 'Builder.setup_package("sys-boot/grub")',
          'condition': lambda Get: (Get('os_root_type') == "hdd" and
                                    Get('builder.cl_builder_livemenu_path') !=
